@@ -1,7 +1,7 @@
-"""This module provides an API for deploying MLFlow models to Google Cloud Vertex AI.
+"""This module provides an API for deploying MLflow models to Google Cloud Vertex AI.
 
 The `upload_mlflow_model_to_vertex_ai_models` function builds a Docker container
-for a given MLFlow model and pushes the image to Google Container Registry.
+for a given MLflow model and pushes the image to Google Container Registry.
 Then it registers the model as a Google Cloud Vertex AI Model.
 Once the model is registered, the user can deploy it for serving on Google Cloud
 Vertex AI Endpoint using the `deploy_gcp_model_to_new_endpoint` function.
@@ -11,7 +11,7 @@ for more information.
 
 Examples::
 
-    # Use MLFlow to register the model on Cloud AI Platform
+    # Use MLflow to register the model on Cloud AI Platform
     model_uri = "models:/mymodel/mymodelversion" # Replace with your model URI
     display_name = "my_mlflow_model" # Replace with the desired model name
 
@@ -46,8 +46,8 @@ _logger = logging.getLogger(__name__)
 
 
 def get_fixed_mlflow_source_dir():
-    """Downloads the fixed MLFlow source code."""
-    fixed_mlflow_archive_url = "https://github.com/Ark-kun/mlflow/zipball/MLFlow-fixes"
+    """Downloads the fixed MLflow source code."""
+    fixed_mlflow_archive_url = "https://github.com/Ark-kun/mlflow/archive/refs/heads/MLFlow-fixes.zip"
     fixed_mlflow_archive_path, _ = urllib.request.urlretrieve(url=fixed_mlflow_archive_url)
     fixed_mlflow_parent_dir = tempfile.mkdtemp(prefix="mlflow.fixed")
     with zipfile.ZipFile(fixed_mlflow_archive_path, 'r') as zip_ref:
@@ -68,9 +68,9 @@ def upload_mlflow_model_to_vertex_ai_models(
     location: str = "us-central1",
     timeout: int = 1800,
 ) -> str:
-    """Builds a container for an MLFlow model and registers the model with Google Cloud Vertex AI.
+    """Builds a container for an MLflow model and registers the model with Google Cloud Vertex AI.
 
-    The resulting container image will contain the MLFlow webserver that processes
+    The resulting container image will contain the MLflow webserver that processes
     prediction requests. The container image can be deployed as a web service to
     Vertex AI Endpoints.
 
@@ -107,7 +107,7 @@ def upload_mlflow_model_to_vertex_ai_models(
 
     Examples::
 
-        # Use MLFlow to register the model on Google Cloud Vertex AI
+        # Use MLflow to register the model on Google Cloud Vertex AI
         model_uri = "models:/mymodel/mymodelversion" # Replace with your model URI
         display_name = "my_mlflow_model" # Replace with the desired model name
 
@@ -142,10 +142,7 @@ def upload_mlflow_model_to_vertex_ai_models(
     pushed_image_uri_with_digest = _build_serving_image(
         model_uri=model_uri,
         destination_image_uri=destination_image_uri,
-        # TODO(avolkov): Remove when the fixes are merged:
-        # https://github.com/mlflow/mlflow/pull/4609
-        # https://github.com/mlflow/mlflow/pull/4611
-        mlflow_source_dir=get_fixed_mlflow_source_dir()
+        mlflow_source_dir=None,
     )
 
     upload_model_response = _upload_model(
@@ -163,14 +160,14 @@ def _build_serving_image(
     destination_image_uri: str,
     mlflow_source_dir: Optional[str] = None,
 ) -> str:
-    """Builds and pushes an MLFlow serving image for the MLFlow model.
+    """Builds and pushes an MLflow serving image for the MLflow model.
 
     Args:
       model_uri: The URI of the MLflow model.
       destination_image_uri: The full name of the container image that will
         be built with the provided model inside it.
         The format should be `gcr.io/<REPO>/<IMAGE>:<TAG>`.
-      mlflow_source_dir: If set, installs MLFlow from this directory instead of
+      mlflow_source_dir: If set, installs MLflow from this directory instead of
         PyPI.
     Returns:
       Fully-qualified URI of the pushed container image including the hash digest.
@@ -331,7 +328,7 @@ def deploy_vertex_ai_model_to_endpoint(
 
     Examples::
 
-        # Use MLFlow to register the model on Cloud AI Platform
+        # Use MLflow to register the model on Cloud AI Platform
         model_uri = "models:/mymodel/mymodelversion" # Replace with your model URI
         display_name = "my_mlflow_model" # Replace with the desired model name
 
